@@ -3,12 +3,12 @@
 
 #include "supclust.h"
 
-#define CDEF(name)  {#name, (DL_FUNC) &name, sizeof(name ## _t)/sizeof(name ## _t[0]), name ##_t}
+#define CDEF(name)  {#name, (DL_FUNC) &name, sizeof(name ## _typ)/sizeof(name ## _typ[0]), name ##_typ}
 #define CALLDEF(name, n)  {#name, (DL_FUNC) &name, n}
 
 // pelora.c --------------------------------------------
 
-static R_NativePrimitiveArgType R_clusterer_t[] = {
+static R_NativePrimitiveArgType R_clusterer_typ[] = {
     REALSXP, REALSXP, REALSXP, REALSXP, REALSXP,
     /* probini */ REALSXP, REALSXP, REALSXP, INTSXP,
     /* g */       INTSXP, INTSXP, INTSXP, INTSXP, INTSXP,
@@ -18,7 +18,7 @@ static R_NativePrimitiveArgType R_clusterer_t[] = {
 
 // wilma.c --------------------------------------------
 
-static R_NativePrimitiveArgType R_multicluster_t[] = {
+static R_NativePrimitiveArgType R_multicluster_typ[] = {
     REALSXP, INTSXP,
     INTSXP, INTSXP, INTSXP,
     INTSXP, INTSXP,
@@ -28,11 +28,11 @@ static R_NativePrimitiveArgType R_multicluster_t[] = {
     INTSXP, INTSXP
 };
 
-static R_NativePrimitiveArgType R_margin_t[] = {
+static R_NativePrimitiveArgType R_margin_typ[] = {
     REALSXP, INTSXP, INTSXP, REALSXP
 };
 
-static R_NativePrimitiveArgType R_score_t[] = {
+static R_NativePrimitiveArgType R_score_typ[] = {
     REALSXP, INTSXP, INTSXP, REALSXP
 };
 
